import { ActionIcon, MantineColorScheme } from '@mantine/core'
import { IconApi, IconArrowBackUp, IconArrowsMove, IconCircle, IconExclamationCircle, IconLine, IconPoint, IconPolygon, IconRuler } from '@tabler/icons-react'
import { Type } from 'ol/geom/Geometry'
import React from 'react'

interface IToolbarProps {
    currentTool: Type | null;
    onSave: () => void;
    onRemove: () => void;
    handleToolSelect: (tool: Type) => void;
    onMover: () => void;
    colorScheme: MantineColorScheme;
}

const MapToolbar = ({
    currentTool,
    onSave,
    onRemove,
    handleToolSelect,
    onMover,
    colorScheme
}: IToolbarProps) => {
    return (
        <ActionIcon.Group orientation='vertical' pos='absolute' top='8px' right='8px' style={{ zIndex: 1, backdropFilter: 'blur(8px)', backgroundColor: colorScheme === 'light' ? '#FFFFFFAA' : '#000000AA', borderRadius: '4px' }}>
            <ActionIcon size='lg' variant='transparent' onClick={() => {
                fetch(`${import.meta.env.VITE_API_EMS_URL}/hello`, { method: 'GET' }).then(res => console.log(res))
            }}>
                <IconApi />
            </ActionIcon>

            <ActionIcon size='lg' variant='transparent' onClick={onSave}>
                <IconExclamationCircle />
            </ActionIcon>

            <ActionIcon size='lg' variant='transparent' onClick={onRemove}>
                <IconArrowBackUp />
            </ActionIcon>

            <ActionIcon
                size='lg'
                variant={currentTool === 'Point' ? 'filled' : 'transparent'}
                onClick={() => {
                    handleToolSelect('Point')
                }}>
                <IconPoint />
            </ActionIcon>

            <ActionIcon
                size='lg'
                variant={currentTool === 'LineString' ? 'filled' : 'transparent'}
                onClick={() => {
                    handleToolSelect('LineString')
                }}>
                <IconLine />
            </ActionIcon>

            <ActionIcon
                size='lg'
                variant={currentTool === 'Polygon' ? 'filled' : 'transparent'}
                onClick={() => {
                    handleToolSelect('Polygon')
                }}>
                <IconPolygon />
            </ActionIcon>

            <ActionIcon
                size='lg'
                variant={currentTool === 'Circle' ? 'filled' : 'transparent'}
                onClick={() => {
                    handleToolSelect('Circle')
                }}>
                <IconCircle />
            </ActionIcon>

            <ActionIcon
                size='lg'
                variant='transparent'
                onClick={onMover}
            >
                <IconArrowsMove />
            </ActionIcon>

            <ActionIcon
                size='lg'
                variant='transparent'
            >
                <IconRuler />
            </ActionIcon>
        </ActionIcon.Group>
    )
}

export default MapToolbar